==> haskell-managed-1.0.6-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: managed
version: 1.0.6
id: managed-1.0.6-KscD4c3BFNIBs32klcB9iz
key: managed-1.0.6-KscD4c3BFNIBs32klcB9iz
license: BSD-3-Clause
copyright: 2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.
    .
    The reason this package defines a specialized version of these types is to:
    .
    * be more beginner-friendly,
    .
    * simplify inferred types and error messages, and:
    .
    * provide some additional type class instances that would otherwise be orphan
    instances
category: Control
abi: e2311102e0f85c85a423aadf753f7f1e
exposed: True
exposed-modules:
    Control.Monad.Managed Control.Monad.Managed.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/managed-1.0.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/managed-1.0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/managed-1.0.6
hs-libraries: HSmanaged-1.0.6-KscD4c3BFNIBs32klcB9iz
depends:
    base-4.11.1.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html: /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-managed-1.0.6-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: managed
version: 1.0.6
id: managed-1.0.6-7sAe2HQnuo86C6EIcX7RDB
key: managed-1.0.6-7sAe2HQnuo86C6EIcX7RDB
license: BSD-3-Clause
copyright: 2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.
    .
    The reason this package defines a specialized version of these types is to:
    .
    * be more beginner-friendly,
    .
    * simplify inferred types and error messages, and:
    .
    * provide some additional type class instances that would otherwise be orphan
    instances
category: Control
abi: 19de535b4fb04732a10ace269d884c4a
exposed: True
exposed-modules:
    Control.Monad.Managed Control.Monad.Managed.Safe
import-dirs: /usr/lib/ghc-8.6.1/site-local/managed-1.0.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/managed-1.0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/managed-1.0.6
hs-libraries: HSmanaged-1.0.6-7sAe2HQnuo86C6EIcX7RDB
depends:
    base-4.12.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html: /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
